searchData={"content_type":"text/markdown","items":[{"doc":"Indexes need to be created and dropped concurrently in order to prevent locking the table in production\n\nAdd these module attributes to your migration file:\n\n@disable_ddl_transaction true\n@disable_migration_lock true\n\nAnd add to the opts of your create/drop index function:\n\nconcurrently: true\n\nIf this is a partitioned table you need to create the index for every partition individually and then do one non-concurrent index build for the whole table. This final build will be much faster as it will just consolidate the individual indexes.\n\nAdd this above that non-concurrent index:\n\n# credo:disable-for-next-line BlitzCredoChecks.ConcurrentIndexMigrations","ref":"BlitzCredoChecks.ConcurrentIndexMigrations.html","title":"BlitzCredoChecks.ConcurrentIndexMigrations","type":"module"},{"doc":"Put your docs before your specs\n\nThis can increase readability by\na.) Enforcing consistent order\nb.) Putting the specs right next to the function head they describe","ref":"BlitzCredoChecks.DocsBeforeSpecs.html","title":"BlitzCredoChecks.DocsBeforeSpecs","type":"module"},{"doc":"Doctest examples should be indented by at least 4 spaces\n\nThis allows ex_doc to render the example in a code block","ref":"BlitzCredoChecks.DoctestIndent.html","title":"BlitzCredoChecks.DoctestIndent","type":"module"},{"doc":"Avoid using imports where possible as they decrease readability and increase compile times\n\nWhen they must be used, use the keyword :only to restrict what is imported","ref":"BlitzCredoChecks.ImproperImport.html","title":"BlitzCredoChecks.ImproperImport","type":"module"},{"doc":"Do not uppercase first letter of a test name\n\nThis is because the test name is appended to the end\nof the describe block name","ref":"BlitzCredoChecks.LowercaseTestNames.html","title":"BlitzCredoChecks.LowercaseTestNames","type":"module"},{"doc":"async: false doesn't do anything as tests are not async by default","ref":"BlitzCredoChecks.NoAsyncFalse.html","title":"BlitzCredoChecks.NoAsyncFalse","type":"module"},{"doc":"Do not use parentheses in DSLs provided by Ecto, Absinthe etc\n\nThis also prevents accidental mass formattings from getting into the main branch\n(from a language server ignoring the .formatter for example)","ref":"BlitzCredoChecks.NoDSLParentheses.html","title":"BlitzCredoChecks.NoDSLParentheses","type":"module"},{"doc":"Use is_binary instead of is_bitstring\n\nThere will be times where is_bitstring is appropriate, but most of the time it is\nbecause the developer is checking for a string and accidentally used the wrong guard\n\nSee: https://elixir-lang.org/getting-started/binaries-strings-and-char-lists.html#binaries","ref":"BlitzCredoChecks.NoIsBitstring.html","title":"BlitzCredoChecks.NoIsBitstring","type":"module"},{"doc":"Ecto Repo calls can only be used within certain contexts, add\nmodules under the :allowed_modules key in .credo.exs\n\nDoes not apply to test files","ref":"BlitzCredoChecks.NoRampantRepos.html","title":"BlitzCredoChecks.NoRampantRepos","type":"module"},{"doc":"All test helpers need to set :warnings_as_errors to true\n\nThis catches things like unused variables, which can be an indication\nthat the developer forgot to pin (^) a variable in a pattern match.\n\nAnd also, clean up your warnings, we arn't living in a barn!","ref":"BlitzCredoChecks.SetWarningsAsErrorsInTest.html","title":"BlitzCredoChecks.SetWarningsAsErrorsInTest","type":"module"},{"doc":"Use ===/2 instead of ==/2 and !==/2 instead of !=/2 for strict float comparison.\nSee `https://elixirschool.com/en/lessons/basics/basics#comparison-12`","ref":"BlitzCredoChecks.StrictComparison.html","title":"BlitzCredoChecks.StrictComparison","type":"module"},{"doc":"Todos in codebase need an associated ticket URL\ni.e.\n\n# Todo: Make this better\n# https://linear.app/company/issue/443","ref":"BlitzCredoChecks.TodosNeedTickets.html","title":"BlitzCredoChecks.TodosNeedTickets","type":"module"},{"doc":"Use Stream functions instead of piping multiple Enum functions together\n\nThis can reduce memory usage, especially in the case of long chains of Enum functions\nSee: `https://hexdocs.pm/elixir/Stream.html`","ref":"BlitzCredoChecks.UseStream.html","title":"BlitzCredoChecks.UseStream","type":"module"},{"doc":"Checks all files that have been changed from trunk. Great for gradually introducing conventions\nthrough enforcement on new code only.\n\nRun this task with `mix credo_diff`\n\nFlags\n\n- `--trunk` the branch that the current one will be compared against for files. Defaults to `main`.\n- `--name` The configuration in .credo.exs to use, defaults to `default`.","ref":"Mix.Tasks.CredoDiff.html","title":"mix credo_diff","type":"task"},{"doc":"It's clunky but each file name has to be appended one at a time","ref":"Mix.Tasks.CredoDiff.html#build_credo_args/2","title":"Mix.Tasks.CredoDiff.build_credo_args/2","type":"function"},{"doc":"There will be other files but we only want to check Elixir","ref":"Mix.Tasks.CredoDiff.html#filter_elixir_files/1","title":"Mix.Tasks.CredoDiff.filter_elixir_files/1","type":"function"},{"doc":"Print any errors we see and error if there is a non-zero exit code","ref":"Mix.Tasks.CredoDiff.html#parse_credo_output/2","title":"Mix.Tasks.CredoDiff.parse_credo_output/2","type":"function"},{"doc":"If we don't get files then there is nothing to check","ref":"Mix.Tasks.CredoDiff.html#parse_git_diff_output/1","title":"Mix.Tasks.CredoDiff.parse_git_diff_output/1","type":"function"},{"doc":"# BlitzCredoChecks\n\n[![Build Status](https://github.com/theblitzapp/blitz_credo_checks/workflows/Coveralls/badge.svg)](https://github.com/theblitzapp/blitz_credo_checks) [![Build Status](https://github.com/theblitzapp/blitz_credo_checks/workflows/Dialyzer/badge.svg)](https://github.com/theblitzapp/blitz_credo_checks) [![Build Status](https://github.com/theblitzapp/blitz_credo_checks/workflows/Credo/badge.svg)](https://github.com/theblitzapp/blitz_credo_checks)  [![Build Status](https://github.com/theblitzapp/blitz_credo_checks/workflows/Doctor/badge.svg)](https://github.com/theblitzapp/blitz_credo_checks) [![codecov](https://codecov.io/gh/theblitzapp/blitz_credo_checks/branch/main/graph/badge.svg?token=pUANTwdjLw)](https://codecov.io/gh/theblitzapp/blitz_credo_checks) [![hex.pm](http://img.shields.io/hexpm/v/blitz_credo_checks.svg?style=flat)](https://hex.pm/packages/blitz_credo_checks)\n\nA set of custom checks used by the Blitz Backend Elixir team on top of the excellent ones included with [Credo](https://github.com/rrrene/credo). We use these checks to catch errors, improve code quality, maintain consistency, and shorten pull request review times.\n\nCheck the moduledocs inside the check modules themselves for details on the individual checks.","ref":"README.md.html","title":"BlitzCredoChecks","type":"extras"},{"doc":"#","ref":"README.md.html#using-these-checks","title":"Using these checks - BlitzCredoChecks","type":"extras"},{"doc":"Add Credo (required to run the checks) and BlitzCredoChecks to your project dependencies by adding the following to your `mix.exs`\n\n```elixir\ndefp deps do\n  [\n    {:credo, \"~> 1.6\", only: [:dev, :test], runtime: false},\n    {:blitz_credo_checks, \"~> 0.1\", only: [:dev, :test], runtime: false}\n  ]\nend\n```\n\n#","ref":"README.md.html#1-add-dependencies","title":"1. Add dependencies - BlitzCredoChecks","type":"extras"},{"doc":"If you do not have one already in the root of your project, a default Credo configuration file `.credo.exs` can be generated with\n\n```bash\nmix credo.gen.config\n```\n\n#","ref":"README.md.html#2-create-configuration-file","title":"2. Create configuration file - BlitzCredoChecks","type":"extras"},{"doc":"Add some or all of these checks under the checks key in `.credo.exs`\n\n```elixir\n      checks: [\n        # Custom checks\n        {BlitzCredoChecks.ConcurrentIndexMigrations, []},\n        {BlitzCredoChecks.DocsBeforeSpecs, []},\n        {BlitzCredoChecks.DoctestIndent, []},\n        {BlitzCredoChecks.ImproperImport, []}, \n        {BlitzCredoChecks.LowercaseTestNames, []},\n        {BlitzCredoChecks.NoAsyncFalse, []},\n        {BlitzCredoChecks.NoDSLParentheses, []},\n        {BlitzCredoChecks.NoIsBitstring, []},\n        {BlitzCredoChecks.NoRampantRepos, []},\n        {BlitzCredoChecks.SetWarningsAsErrorsInTest, []},\n        {BlitzCredoChecks.StrictComparison, []},\n        {BlitzCredoChecks.TodosNeedTickets, ticket_url: \"https://linear.app/company/issue/\"},\n        {BlitzCredoChecks.UseStream, []},\n        \n        # ... all the other checks that come with Credo\n      ]\n```\n\n#","ref":"README.md.html#3-add-these-checks","title":"3. Add these checks - BlitzCredoChecks","type":"extras"},{"doc":"```bash\nmix credo\n```","ref":"README.md.html#4-run-credo","title":"4. Run Credo - BlitzCredoChecks","type":"extras"},{"doc":"This library also contains `Mix.Tasks.CredoDiff` which can run Credo checks across the subset of files that differ from a branch like `main`. This can be useful for incrementally improving the codebase through only applying certain checks on files that are currently being edited.\n\n```bash\nmix credo_diff --trunk main --name stricter_checks\n```\n\nSee `Mix.Tasks.CredoDiff` for more details.","ref":"README.md.html#credodiff","title":"CredoDiff - BlitzCredoChecks","type":"extras"},{"doc":"We welcome contributions to this library. Bear in mind however that new checks can be very controversial as they have a large impact on developer experience. We therefore recommend that you open an issue to discuss a new check before beginning work on a new one.\n\n#","ref":"README.md.html#contributing","title":"Contributing - BlitzCredoChecks","type":"extras"},{"doc":"1. Consider opening an issue for discussion\n2. Fork and clone this repository on GitHub\n3. Install elixir and erlang versions with `asdf`\n\n```bash\nasdf install\n```\n\n4. Fetch dependencies\n\n```bash\nmix deps.get\n```\n\n5. Run the test suite\n\n```bash\nmix check\n```\n\n6. Use your work in another project\n\nIt is an excellent idea to not just write tests, but to also run your check against another codebase.\n\nInclude your cloned project under `deps` in the `mix.exs` of your other codebase\n\n```elixir\n{:blitz_credo_checks, path: \"/home/username/dev/blitz_credo_checks/\"}\n```\n\nAnd fetch your dependencies to pull in the local version you are working on\n\n```bash\nmix deps.get\n```\n\n#","ref":"README.md.html#getting-set-up-locally","title":"Getting set up locally - BlitzCredoChecks","type":"extras"},{"doc":"Are you looking for a new gig?? We're looking for mid-level to senior level developers to join our team and continue growing our platform while building awesome software!\n\nCome join us at [Blitz.gg](https://blitz.gg/careers)","ref":"README.md.html#hiring","title":"Hiring - BlitzCredoChecks","type":"extras"},{"doc":"# Changelog","ref":"CHANGELOG.md.html","title":"Changelog","type":"extras"},{"doc":"","ref":"CHANGELOG.md.html#unreleased","title":"Unreleased - Changelog","type":"extras"},{"doc":"- De-duplicate `TodosNeedTickets`\n- Update Elixir and OTP versions\n- Use single file for CI\n- Add auto merge for Dependabot updates","ref":"CHANGELOG.md.html#v0-1-9-2023-11-28","title":"v0.1.9 (2023-11-28) - Changelog","type":"extras"},{"doc":"- Don't enforce concurrency when dropping indexes","ref":"CHANGELOG.md.html#v0-1-8-2023-05-01","title":"v0.1.8 (2023-05-01) - Changelog","type":"extras"},{"doc":"- Fix for `UseStreamTest` where it had a false positive on adjacent Enum functions that were not piped into each other","ref":"CHANGELOG.md.html#v0-1-7-2022-09-26","title":"v0.1.7 (2022-09-26) - Changelog","type":"extras"},{"doc":"- allowed_modules option for `ImproperImport` can now take a list of atoms as well as a list of lists\n- Add `:consecutive_lines` option to `UseStream`\n- Add `ConcurrentIndexMigrations` check","ref":"CHANGELOG.md.html#v0-1-6-2022-06-28","title":"v0.1.6 (2022-06-28) - Changelog","type":"extras"},{"doc":"- Make Credo available for prod build to resolve OTP 25 errors on release\n- Update OTP/Elixir versions\n- Minor dependency updates","ref":"CHANGELOG.md.html#v0-1-5-2022-05-26","title":"v0.1.5 (2022-05-26) - Changelog","type":"extras"},{"doc":"- Fix CI checks names\n- Enforce that indentation is at least 4 characters in `DoctestIndent`","ref":"CHANGELOG.md.html#v0-1-4-2022-04-25","title":"v0.1.4 (2022-04-25) - Changelog","type":"extras"},{"doc":"- Fix print statements not showing in console for credo_diff errors","ref":"CHANGELOG.md.html#v0-1-3-2022-04-12","title":"v0.1.3 (2022-04-12) - Changelog","type":"extras"},{"doc":"- Added check\n  - `TodoNeedsTickets`","ref":"CHANGELOG.md.html#v0-1-2-2022-04-12","title":"v0.1.2 (2022-04-12) - Changelog","type":"extras"},{"doc":"- Added CredoDiff task that runs Credo on files that have changed from trunk\n- Added checks\n  - `ImproperImport`\n  - `NoRampantRepos`","ref":"CHANGELOG.md.html#v0-1-1-2022-04-11","title":"v0.1.1 (2022-04-11) - Changelog","type":"extras"},{"doc":"- Added checks\n  - `DocsBeforeSpecs`\n  - `DoctestIndent`\n  - `LowercaseTestNames`\n  - `NoAsyncFalse`\n  - `NoDSLParentheses`\n  - `NoIsBitstring`\n  - `SetWarningsAsErrorsInTest`\n  - `StrictComparison`\n  - `UseStream`\n- General documentation and tooling","ref":"CHANGELOG.md.html#v0-1-0-2022-04-08","title":"v0.1.0 (2022-04-08) - Changelog","type":"extras"},{"doc":"- Created the project!","ref":"CHANGELOG.md.html#created-repo-2022-04-07","title":"Created Repo (2022-04-07) - Changelog","type":"extras"}]}